==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/UploadDataCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { UploadDataCompletedEventArgsDescription } from "./UploadDataCompletedEventArgsDescription";
/**
 * @hidden
 */
var UploadDataCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(UploadDataCompletedEventArgsDescriptionMetadata, _super);
    function UploadDataCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UploadDataCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (UploadDataCompletedEventArgsDescriptionMetadata.a == null) {
            UploadDataCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            UploadDataCompletedEventArgsDescriptionMetadata.c(UploadDataCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.k(UploadDataCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(UploadDataCompletedEventArgsDescriptionMetadata.a);
    };
    UploadDataCompletedEventArgsDescriptionMetadata.c = function (a) {
        AsyncCompletedEventArgsDescriptionMetadata.c(a);
    };
    UploadDataCompletedEventArgsDescriptionMetadata.d = function (a) {
        UploadDataCompletedEventArgsDescriptionMetadata.b(a);
        a.ad("UploadDataCompletedEventArgs", function () { return new UploadDataCompletedEventArgsDescription(); });
        a.ac("UploadDataCompletedEventArgs", UploadDataCompletedEventArgsDescriptionMetadata.a);
    };
    UploadDataCompletedEventArgsDescriptionMetadata.$t = markType(UploadDataCompletedEventArgsDescriptionMetadata, 'UploadDataCompletedEventArgsDescriptionMetadata');
    UploadDataCompletedEventArgsDescriptionMetadata.a = null;
    return UploadDataCompletedEventArgsDescriptionMetadata;
}(Base));
export { UploadDataCompletedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/UploadDataCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { UploadDataCompletedEventArgsDescription } from "./UploadDataCompletedEventArgsDescription";
/**
 * @hidden
 */
var UploadDataCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(UploadDataCompletedEventArgsDescriptionMetadata, _super);
    function UploadDataCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UploadDataCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (UploadDataCompletedEventArgsDescriptionMetadata.a == null) {
            UploadDataCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            UploadDataCompletedEventArgsDescriptionMetadata.c(UploadDataCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.k(UploadDataCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(UploadDataCompletedEventArgsDescriptionMetadata.a);
    };
    UploadDataCompletedEventArgsDescriptionMetadata.c = function (a) {
        AsyncCompletedEventArgsDescriptionMetadata.c(a);
    };
    UploadDataCompletedEventArgsDescriptionMetadata.d = function (a) {
        UploadDataCompletedEventArgsDescriptionMetadata.b(a);
        a.ae("UploadDataCompletedEventArgs", function () { return new UploadDataCompletedEventArgsDescription(); });
        a.ad("UploadDataCompletedEventArgs", UploadDataCompletedEventArgsDescriptionMetadata.a);
    };
    UploadDataCompletedEventArgsDescriptionMetadata.$t = markType(UploadDataCompletedEventArgsDescriptionMetadata, 'UploadDataCompletedEventArgsDescriptionMetadata');
    UploadDataCompletedEventArgsDescriptionMetadata.a = null;
    return UploadDataCompletedEventArgsDescriptionMetadata;
}(Base));
export { UploadDataCompletedEventArgsDescriptionMetadata };
